@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2008 IBM Corporation and others.
+ * Copyright (c) 2008, 2018 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -10,6 +10,8 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
+ *     Inno-Tec Innovative Technologies GmbH - Fix for Bug 388055
+ *
  *******************************************************************************/
 package org.eclipse.equinox.security.tests;
 
@@ -23,7 +25,7 @@ import org.junit.runners.Suite.SuiteClasses;
  * As such this tests should be run in a headless mode.
  */
 @RunWith(Suite.class)
-@SuiteClasses({Base64Test.class, SlashEncodeTest.class, DefaultPreferencesTest.class, DynamicPreferencesTest.class, WinPreferencesTest.class})
+@SuiteClasses({Base64Test.class, DetectPBECiphersTest.class, SlashEncodeTest.class, DefaultPreferencesTest.class, DynamicPreferencesTest.class, WinPreferencesTest.class})
 public class AllSecurityTests {
 	//see @SuiteClasses
 }
